@@ -34,6 +34,7 @@
 #include <QGuiApplication>
 #include <QDialogButtonBox>
 #include <QScreen>
+#include <QStandardPaths>
 
 #include <QDBusConnection>
 #include <QDBusInterface>
@@ -71,8 +72,8 @@ KHintsSettings::KHintsSettings(KSharedConfig::Ptr kdeglobals)
         mLnfConfig = KSharedConfig::openConfig(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("plasma/look-and-feel/") + defaultLookAndFeelPackage + QStringLiteral("/contents/defaults")));
     }
 
-
-    m_hints[QPlatformTheme::CursorFlashTime] = qBound(200, cg.readEntry("CursorBlinkRate", 1000), 2000);
+    const auto cursorBlinkRate = cg.readEntry("CursorBlinkRate", 1000);
+    m_hints[QPlatformTheme::CursorFlashTime] = cursorBlinkRate > 0 ? qBound(200, cursorBlinkRate, 2000) : 0; // 0 => no blinking
     m_hints[QPlatformTheme::MouseDoubleClickInterval] = cg.readEntry("DoubleClickInterval", 400);
     m_hints[QPlatformTheme::StartDragDistance] = cg.readEntry("StartDragDist", 10);
     m_hints[QPlatformTheme::StartDragTime] = cg.readEntry("StartDragTime", 500);
@@ -120,8 +121,7 @@ KHintsSettings::KHintsSettings(KSharedConfig::Ptr kdeglobals)
         QApplication::setWheelScrollLines(cg.readEntry("WheelScrollLines", 3));
     }
 
-    bool showIcons = cg.readEntry("ShowIconsInMenuItems", !QApplication::testAttribute(Qt::AA_DontShowIconsInMenus));
-    QCoreApplication::setAttribute(Qt::AA_DontShowIconsInMenus, !showIcons);
+    updateShowIconsInMenuItems(cg);
 
     QMetaObject::invokeMethod(this, "delayedDBusConnects", Qt::QueuedConnection);
     QMetaObject::invokeMethod(this, "setupIconLoader", Qt::QueuedConnection);
@@ -168,24 +168,14 @@ QStringList KHintsSettings::xdgIconThemePaths() const
 {
     QStringList paths;
 
+    // make sure we have ~/.local/share/icons in paths if it exists
+    paths << QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("icons"), QStandardPaths::LocateDirectory);
+
     const QFileInfo homeIconDir(QDir::homePath() + QStringLiteral("/.icons"));
     if (homeIconDir.isDir()) {
         paths << homeIconDir.absoluteFilePath();
     }
 
-    QString xdgDirString = QFile::decodeName(qgetenv("XDG_DATA_DIRS"));
-
-    if (xdgDirString.isEmpty()) {
-        xdgDirString = QStringLiteral("/usr/local/share:/usr/share");
-    }
-
-    foreach (const QString &xdgDir, xdgDirString.split(QLatin1Char(':'))) {
-        const QFileInfo xdgIconsDir(xdgDir + QStringLiteral("/icons"));
-        if (xdgIconsDir.isDir()) {
-            paths << xdgIconsDir.absoluteFilePath();
-        }
-    }
-
     return paths;
 }
 
@@ -250,6 +240,8 @@ void KHintsSettings::slotNotifyChange(int type, int arg)
         } else if (category == SETTINGS_STYLE) {
             m_hints[QPlatformTheme::DialogButtonBoxButtonsHaveIcons] = cg.readEntry("ShowIconsOnPushButtons", true);
             m_hints[QPlatformTheme::UiEffects] = cg.readEntry("GraphicEffectsLevel", 0) != 0 ? QPlatformTheme::GeneralUiEffect : 0;
+
+            updateShowIconsInMenuItems(cg);
         }
         break;
     }
@@ -341,8 +333,7 @@ void KHintsSettings::updateQtSettings(KConfigGroup &cg)
 
     m_hints[QPlatformTheme::ItemViewActivateItemOnSingleClick] = cg.readEntry("SingleClick", true);
 
-    bool showIcons = cg.readEntry("ShowIconsInMenuItems", !QApplication::testAttribute(Qt::AA_DontShowIconsInMenus));
-    QCoreApplication::setAttribute(Qt::AA_DontShowIconsInMenus, !showIcons);
+    updateShowIconsInMenuItems(cg);
 
     int wheelScrollLines = cg.readEntry("WheelScrollLines", 3);
     m_hints[QPlatformTheme::WheelScrollLines] = wheelScrollLines;
@@ -352,6 +343,12 @@ void KHintsSettings::updateQtSettings(KConfigGroup &cg)
     }
 }
 
+void KHintsSettings::updateShowIconsInMenuItems(KConfigGroup &cg)
+{
+    bool showIcons = cg.readEntry("ShowIconsInMenuItems", true);
+    QCoreApplication::setAttribute(Qt::AA_DontShowIconsInMenus, !showIcons);
+}
+
 Qt::ToolButtonStyle KHintsSettings::toolButtonStyle(const KConfigGroup &cg) const
 {
     const QString buttonStyle = cg.readEntry("ToolButtonStyle", "TextBesideIcon").toLower();
